==> haskell-quickcheck-instances-0.3.30-172-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 quickcheck-instances
version:              0.3.30
visibility:           public
id:                   quickcheck-instances-0.3.30-IX8gBBNEvZfE4usplPWVlR
key:                  quickcheck-instances-0.3.30-IX8gBBNEvZfE4usplPWVlR
license:              BSD-3-Clause
copyright:            Copyright 2012-2016 Antoine Latter, 2017-2019 Oleg Grenrus
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:
    Antoine Latter <aslatter@gmail.com>, Oleg Grenrus <oleg.grenrus@iki.fi>

homepage:             https://github.com/haskellari/qc-instances
synopsis:             Common quickcheck instances
description:
    QuickCheck instances.

    The goal is to supply QuickCheck instances for
    types provided by the Haskell Platform.

    Since all of these instances are provided as
    orphans, I recommend that you do not use this library
    within another library module, so that you don'\''t
    impose these instances on down-stream consumers of
    your code.

category:             Testing
abi:                  6cf449ee6c04feeabce146d5a72ab2db
exposed:              True
exposed-modules:
    Test.QuickCheck.Instances Test.QuickCheck.Instances.Array
    Test.QuickCheck.Instances.Array.Byte
    Test.QuickCheck.Instances.ByteString
    Test.QuickCheck.Instances.CaseInsensitive
    Test.QuickCheck.Instances.Containers
    Test.QuickCheck.Instances.DataFix
    Test.QuickCheck.Instances.Hashable
    Test.QuickCheck.Instances.Natural Test.QuickCheck.Instances.OldTime
    Test.QuickCheck.Instances.Primitive
    Test.QuickCheck.Instances.Scientific
    Test.QuickCheck.Instances.Semigroup Test.QuickCheck.Instances.Solo
    Test.QuickCheck.Instances.Strict Test.QuickCheck.Instances.Tagged
    Test.QuickCheck.Instances.Text Test.QuickCheck.Instances.Text.Short
    Test.QuickCheck.Instances.These Test.QuickCheck.Instances.Time
    Test.QuickCheck.Instances.Transformer
    Test.QuickCheck.Instances.UUID
    Test.QuickCheck.Instances.UnorderedContainers
    Test.QuickCheck.Instances.Vector Test.QuickCheck.Instances.Void

hidden-modules:       Test.QuickCheck.Instances.CustomPrelude
import-dirs:          /usr/lib/ghc-9.4.8/site-local/quickcheck-instances-0.3.30
library-dirs:         /usr/lib/ghc-9.4.8/site-local/quickcheck-instances-0.3.30
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/quickcheck-instances-0.3.30
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-instances
hs-libraries:         HSquickcheck-instances-0.3.30-IX8gBBNEvZfE4usplPWVlR
depends:
    OneTuple-0.4.2-JCo97y3vRnM9FXkOt3LjRA
    QuickCheck-2.14.3-3CoFGl7CagbATKlXLaYDNP array-0.5.4.0
    base-4.17.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-9695IAuXzI9BpRD3yNxY1D containers-0.6.7
    data-fix-0.3.3-5pLCRgeyFsi655zIxn2R2V
    hashable-1.4.4.0-HA5jWeGkLE053htWZjUgjX
    integer-logarithms-1.0.4-IeiZNOHndtHBlUxCWzOJUr
    old-time-1.1.0.4-7kNg8VzooGoExH4yeT9sv9
    primitive-0.8.0.0-2MtTSGoMYmP3ESqdIhZDu7
    scientific-0.3.7.0-6O6FbUTzbTcBhAh2dckDIt
    splitmix-0.1.0.5-AJytuwX1oldJNAOpDcZFXk
    strict-0.5-zwxOOXQRn7E5xzO8v1Ong
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C text-2.0.2
    text-short-0.1.6-DFy7kIIkCnA3mhKjYr8Fzb
    these-1.2-4vq2ddt04VSB6DmAwfkBie time-1.12.2
    time-compat-1.9.6.1-4BqJzfqka1qFYKmFqWwyvv transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ
    unordered-containers-0.2.20-Jl6TkouWI2i1D1jczNV0uv
    uuid-types-1.0.6-EAyU5TCdvqlLJTPebGDmU9
    vector-0.13.2.0-F0gUvA5SUIr11j4RVHYOTP

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-instances/html/quickcheck-instances.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-instances/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-quickcheck-instances-0.3.30-173-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 quickcheck-instances
version:              0.3.30
visibility:           public
id:                   quickcheck-instances-0.3.30-3fWeKkjJuM84lWDnkIeaqX
key:                  quickcheck-instances-0.3.30-3fWeKkjJuM84lWDnkIeaqX
license:              BSD-3-Clause
copyright:            Copyright 2012-2016 Antoine Latter, 2017-2019 Oleg Grenrus
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:
    Antoine Latter <aslatter@gmail.com>, Oleg Grenrus <oleg.grenrus@iki.fi>

homepage:             https://github.com/haskellari/qc-instances
synopsis:             Common quickcheck instances
description:
    QuickCheck instances.

    The goal is to supply QuickCheck instances for
    types provided by the Haskell Platform.

    Since all of these instances are provided as
    orphans, I recommend that you do not use this library
    within another library module, so that you don'\''t
    impose these instances on down-stream consumers of
    your code.

category:             Testing
abi:                  d060aac8bdcd7f89632f095432ebc6fb
exposed:              True
exposed-modules:
    Test.QuickCheck.Instances Test.QuickCheck.Instances.Array
    Test.QuickCheck.Instances.Array.Byte
    Test.QuickCheck.Instances.ByteString
    Test.QuickCheck.Instances.CaseInsensitive
    Test.QuickCheck.Instances.Containers
    Test.QuickCheck.Instances.DataFix
    Test.QuickCheck.Instances.Hashable
    Test.QuickCheck.Instances.Natural Test.QuickCheck.Instances.OldTime
    Test.QuickCheck.Instances.Primitive
    Test.QuickCheck.Instances.Scientific
    Test.QuickCheck.Instances.Semigroup Test.QuickCheck.Instances.Solo
    Test.QuickCheck.Instances.Strict Test.QuickCheck.Instances.Tagged
    Test.QuickCheck.Instances.Text Test.QuickCheck.Instances.Text.Short
    Test.QuickCheck.Instances.These Test.QuickCheck.Instances.Time
    Test.QuickCheck.Instances.Transformer
    Test.QuickCheck.Instances.UUID
    Test.QuickCheck.Instances.UnorderedContainers
    Test.QuickCheck.Instances.Vector Test.QuickCheck.Instances.Void

hidden-modules:       Test.QuickCheck.Instances.CustomPrelude
import-dirs:          /usr/lib/ghc-9.4.8/site-local/quickcheck-instances-0.3.30
library-dirs:         /usr/lib/ghc-9.4.8/site-local/quickcheck-instances-0.3.30
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/quickcheck-instances-0.3.30
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-instances
hs-libraries:         HSquickcheck-instances-0.3.30-3fWeKkjJuM84lWDnkIeaqX
depends:
    OneTuple-0.4.2-JCo97y3vRnM9FXkOt3LjRA
    QuickCheck-2.14.3-3CoFGl7CagbATKlXLaYDNP array-0.5.4.0
    base-4.17.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-9695IAuXzI9BpRD3yNxY1D containers-0.6.7
    data-fix-0.3.3-5pLCRgeyFsi655zIxn2R2V
    hashable-1.4.4.0-HA5jWeGkLE053htWZjUgjX
    integer-logarithms-1.0.4-IeiZNOHndtHBlUxCWzOJUr
    old-time-1.1.0.4-7kNg8VzooGoExH4yeT9sv9
    primitive-0.8.0.0-2MtTSGoMYmP3ESqdIhZDu7
    scientific-0.3.7.0-6O6FbUTzbTcBhAh2dckDIt
    splitmix-0.1.0.5-AJytuwX1oldJNAOpDcZFXk
    strict-0.5-bvsa409NlOCGwtet0fOUL
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C text-2.0.2
    text-short-0.1.6-DFy7kIIkCnA3mhKjYr8Fzb
    these-1.2-K2ZJFQ14cOa6i0KNKejLwH time-1.12.2
    time-compat-1.9.6.1-4BqJzfqka1qFYKmFqWwyvv transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ
    unordered-containers-0.2.20-Jl6TkouWI2i1D1jczNV0uv
    uuid-types-1.0.6-EAyU5TCdvqlLJTPebGDmU9
    vector-0.13.2.0-F0gUvA5SUIr11j4RVHYOTP

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-instances/html/quickcheck-instances.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-instances/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
